[Erp5-report] r7376 - /erp5/trunk/products/ERP5Type/tests/testXMLMatrix.py

nobody at svn.erp5.org nobody at svn.erp5.org
Mon May 22 09:06:42 CEST 2006


Author: alex
Date: Mon May 22 09:06:39 2006
New Revision: 7376

URL: http://svn.erp5.org?rev=7376&view=rev
Log:
- added missing docstrings
- added erp5_base business template to the list

Modified:
    erp5/trunk/products/ERP5Type/tests/testXMLMatrix.py

Modified: erp5/trunk/products/ERP5Type/tests/testXMLMatrix.py
URL: http://svn.erp5.org/erp5/trunk/products/ERP5Type/tests/testXMLMatrix.py?rev=7376&r1=7375&r2=7376&view=diff
==============================================================================
--- erp5/trunk/products/ERP5Type/tests/testXMLMatrix.py (original)
+++ erp5/trunk/products/ERP5Type/tests/testXMLMatrix.py Mon May 22 09:06:39 2006
@@ -50,6 +50,9 @@
   pass
 
 class TestXMLMatrix(ERP5TypeTestCase):
+  """
+  Tests the Cell API
+  """
 
   # Some helper methods
 
@@ -57,14 +60,20 @@
 
   def getBusinessTemplateList(self):
     """
-      Return the list of business templates.
-    """
-    return ('erp5_trade',)
+    Return the list of business templates.
+    """
+    return ('erp5_base', 'erp5_trade',)
 
   def getTitle(self):
+    """
+    Returns the title of the test
+    """
     return "XMLMatrix"
 
   def afterSetUp(self, quiet=1, run=1):
+    """
+    Some pre-configuration
+    """
     LOG('afterSetUp', 0, 'Called')
     uf = self.getPortal().acl_users
     uf._doAddUser('manager', '', ['Manager'], [])
@@ -76,8 +85,10 @@
       order = module.newContent(id='1', portal_type='Purchase Order')
 
   def test_01_RenameCellRange(self):
+    """
+    tests renameCellRange behaviour
+    """
     ZopeTestCase._print('\nTest Rename Cell Range ')
-    # Test if renameCellRange works in XMLMatrix.
     portal = self.getPortal()
     module = portal.purchase_order_module
     order = module._getOb('1')
@@ -181,7 +192,9 @@
       i += 1
 
   def checkSetCellRangeAndCatalog(self,active=1):
     # Test if set Cell range do well catalog and uncatalog
     portal = self.getPortal()
     if not active:
       portal._delObject('portal_activities')
@@ -250,10 +263,17 @@
       self.assertEquals(catalog.hasPath(cell_path),False)
 
   def test_02_SetCellRangeAndCatalogWithActivities(self):
+    """
+    Tests if set Cell range do well catalog and uncatalog, using activities
+    """
     ZopeTestCase._print('\nTest Set Cell Range And Catalog With Activities ')
     self.checkSetCellRangeAndCatalog(active=1)
 
   def test_03_SetCellRangeAndCatalogWithoutActivities(self):
+    """
+    Tests if set Cell range do well catalog and uncatalog, not using
+    activities
+    """
     ZopeTestCase._print('\nTest Set Cell Range And Catalog Without Activities ')
     self.checkSetCellRangeAndCatalog(active=0)
 
@@ -181,7 +192,9 @@
 
   def checkSetCellRangeAndCatalog(self,active=1):
-    # Test if set Cell range do well catalog and uncatalog
+    """
+    Tests if set Cell range do well catalog and uncatalog
+    """
     portal = self.getPortal()
     if not active:




More information about the Erp5-report mailing list